==> module-browser-0.0.56-41.tgz: package/src/file-editor-input-registry.ts <==

import { IEditorInputFactory, IEDITOR_INPUT_ID } from '@workbench-stack/core';
import { ClientTypes } from '@common-stack/client-core';
import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
import {
    FileClientTypenames, EditorsFileRefFragmentDoc, IEditorsFileRefFragment,
    IEditorInput, IFileEditorInput,
} from '@files-stack/core';
import { InMemoryCache } from 'apollo-cache-inmemory';
import { interfaces } from 'inversify';


// Register Editor Input Factory
export class FileEditorInputFactory implements IEditorInputFactory {

    private getFileDetails(resource: string | URI, container: interfaces.Container) {
        const utility: any = container.get(ClientTypes.UtilityClass);
        const cache = container.get<InMemoryCache>(ClientTypes.InMemoryCache);
        const id = utility.getCacheKey({ resource, __typename: FileClientTypenames.FileStatWithMetadata });
        const file = cache.readFragment<IEditorsFileRefFragment>({
            id,
            fragment: EditorsFileRefFragmentDoc,
            variables: { skipValue: true },
        });
        return file;
    }

    public createInput(resource: URI, label: string, encoding: string, mode: string | undefined, container: interfaces.Container) {
        const fileStat = this.getFileDetails(resource, container);
        const pinned = false;
        const result = Object.assign<IEditorInput, IFileEditorInput>(
            {
                isPinned: pinned || false,
                closable: true,
                preview: false,
                isActive: false,
            }, {
            __typename: FileClientTypenames.FileEditorInput,
            description: label,
            typeId: IEDITOR_INPUT_ID.RESOURCE_EDITOR_INPUT as any,
            editorId: 1,
            resource: resource.toString(),
            preferredEncoding: encoding || fileStat.encoding,
            preferredMode: mode || fileStat.preferredMode,
            encoding: fileStat.encoding,
            mode: fileStat.preferredMode,
            fileReference: fileStat as any,
        });

        return result as any; //todo fix after codegen.yaml
    }
}


/**
 * File editor input id.
 */
// export const FILE_EDITOR_INPUT_ID = 'workbench.editors.files.fileEditorInput';

==> module-browser-0.0.56-138.tgz: package/src/file-editor-input-registry.ts <==

import { IEditorInputFactory } from '@workbench-stack/core';
import { ClientTypes } from '@common-stack/client-core';
import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
import {
    FileClientTypenames, EditorsFileRefFragmentDoc, IEditorsFileRefFragment,
    IEditorInput, IFileEditorInput, IEDITOR_INPUT_ID,
} from '@files-stack/core';
import { resourcePath } from '@files-stack/client-state';
import { InMemoryCache } from 'apollo-cache-inmemory';
import { interfaces } from 'inversify';


// Register Editor Input Factory
export class FileEditorInputFactory implements IEditorInputFactory {

    private getFileDetails(resource: string | URI, container: interfaces.Container) {
        const utility: any = container.get(ClientTypes.UtilityClass);
        const cache = container.get<InMemoryCache>(ClientTypes.InMemoryCache);
        const id = utility.getCacheKey({ resource, __typename: FileClientTypenames.FileStatWithMetadata });
        const file = cache.readFragment<IEditorsFileRefFragment>({
            id,
            fragment: EditorsFileRefFragmentDoc,
            variables: { skipValue: true },
        });
        return file;
    }

    public createInput(resource: URI, label: string, encoding: string, mode: string | undefined, container: interfaces.Container) {
        const fileStat = this.getFileDetails(resource, container);
        const pinned = false;
        const result = Object.assign<IEditorInput, IFileEditorInput>(
            {
                isPinned: pinned || false,
                closable: true,
                preview: false,
                isActive: false,
            }, {
            __typename: FileClientTypenames.FileEditorInput,
            id: null,
            description: label,
            typeId: IEDITOR_INPUT_ID.file,
            editorId: 1,
            resource: resourcePath(resource),
            preferredEncoding: encoding || fileStat.encoding,
            preferredMode: mode || fileStat.preferredMode,
            encoding: fileStat.encoding,
            mode: fileStat.preferredMode,
            fileReference: fileStat as any,
        });

        return result as any; //todo fix after codegen.yaml
    }
}


/**
 * File editor input id.
 */
// export const FILE_EDITOR_INPUT_ID = 'workbench.editors.files.fileEditorInput';
